@@ -10,12 +10,48 @@ from prompt_toolkit.shortcuts import confirm
 from taskrepo.core.config import Config
 
 
+def _display_config(config):
+    """Display current configuration in a formatted way."""
+    click.echo()
+    click.secho("-" * 50, fg="green")
+    click.secho("Current Configuration:", fg="green", bold=True)
+    click.secho("-" * 50, fg="green")
+    click.echo(f"  Config file: {config.config_path}")
+    click.echo(f"  Parent directory: {config.parent_dir}")
+    click.echo()
+    click.secho("  Task Defaults:", fg="yellow", bold=True)
+    click.echo(f"  Default priority: {config.default_priority}")
+    click.echo(f"  Default status: {config.default_status}")
+    default_assignee = config.default_assignee if config.default_assignee else "(none)"
+    click.echo(f"  Default assignee: {default_assignee}")
+    default_repo = config.default_repo if config.default_repo else "(none)"
+    click.echo(f"  Default repository: {default_repo}")
+    click.echo()
+    click.secho("  Other Settings:", fg="yellow", bold=True)
+    default_github_org = config.default_github_org if config.default_github_org else "(none)"
+    click.echo(f"  Default GitHub org: {default_github_org}")
+    default_editor = config.default_editor if config.default_editor else "(none - using $EDITOR or vim)"
+    click.echo(f"  Default editor: {default_editor}")
+    sort_by = ", ".join(config.sort_by)
+    click.echo(f"  Sort by: {sort_by}")
+    cluster_status = "enabled" if config.cluster_due_dates else "disabled"
+    click.echo(f"  Due date clustering: {cluster_status}")
+    click.echo(f"  TUI view mode: {config.tui_view_mode}")
+    click.secho("-" * 50, fg="green")
+
+
 @click.command(name="config")
+@click.option("--show", is_flag=True, help="Show current configuration (non-interactive)")
 @click.pass_context
-def config_cmd(ctx):
+def config_cmd(ctx, show):
     """Interactive configuration management."""
     config = ctx.obj["config"]
 
+    # If --show flag is provided, display config and exit
+    if show:
+        _display_config(config)
+        return
+
     while True:
         click.echo()
         click.secho("=" * 50, fg="cyan")
@@ -36,13 +72,14 @@ def config_cmd(ctx):
         click.echo("  8. Set default editor")
         click.echo("  9. Configure task sorting")
         click.echo(" 10. Toggle due date clustering")
-        click.echo("\n 11. Reset to defaults")
-        click.echo(" 12. Exit")
+        click.echo(" 11. Set TUI view mode")
+        click.echo("\n 12. Reset to defaults")
+        click.echo(" 13. Exit")
 
         try:
             choice = prompt(
-                "\nEnter choice (1-12): ",
-                completer=WordCompleter(["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"]),
+                "\nEnter choice (1-13): ",
+                completer=WordCompleter(["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13"]),
             )
         except (KeyboardInterrupt, EOFError):
             click.echo("\nExiting configuration.")
@@ -52,31 +89,7 @@ def config_cmd(ctx):
 
         if choice == "1":
             # View current settings
-            click.echo()
-            click.secho("-" * 50, fg="green")
-            click.secho("Current Configuration:", fg="green", bold=True)
-            click.secho("-" * 50, fg="green")
-            click.echo(f"  Config file: {config.config_path}")
-            click.echo(f"  Parent directory: {config.parent_dir}")
-            click.echo()
-            click.secho("  Task Defaults:", fg="yellow", bold=True)
-            click.echo(f"  Default priority: {config.default_priority}")
-            click.echo(f"  Default status: {config.default_status}")
-            default_assignee = config.default_assignee if config.default_assignee else "(none)"
-            click.echo(f"  Default assignee: {default_assignee}")
-            default_repo = config.default_repo if config.default_repo else "(none)"
-            click.echo(f"  Default repository: {default_repo}")
-            click.echo()
-            click.secho("  Other Settings:", fg="yellow", bold=True)
-            default_github_org = config.default_github_org if config.default_github_org else "(none)"
-            click.echo(f"  Default GitHub org: {default_github_org}")
-            default_editor = config.default_editor if config.default_editor else "(none - using $EDITOR or vim)"
-            click.echo(f"  Default editor: {default_editor}")
-            sort_by = ", ".join(config.sort_by)
-            click.echo(f"  Sort by: {sort_by}")
-            cluster_status = "enabled" if config.cluster_due_dates else "disabled"
-            click.echo(f"  Due date clustering: {cluster_status}")
-            click.secho("-" * 50, fg="green")
+            _display_config(config)
 
         elif choice == "2":
             # Change parent directory
@@ -111,7 +124,7 @@ def config_cmd(ctx):
         elif choice == "4":
             # Set default status
             click.echo(f"\nCurrent default status: {config.default_status}")
-            statuses = ["pending", "in_progress", "completed", "cancelled"]
+            statuses = ["pending", "in-progress", "completed", "cancelled"]
             try:
                 new_status = prompt(
                     "Enter default status: ",
@@ -154,12 +167,16 @@ def config_cmd(ctx):
             if not repositories:
                 click.secho("✗ No repositories found. Create one first with: tsk create-repo", fg="red")
             else:
+                # Sort by task count (descending), then name (ascending)
+                repositories = sorted(repositories, key=lambda r: (-len(r.list_tasks()), r.name))
+
                 current_repo = config.default_repo if config.default_repo else "(none)"
                 click.echo(f"\nCurrent default repository: {current_repo}")
                 click.echo("\nAvailable repositories:")
                 for idx, repo in enumerate(repositories, start=1):
+                    task_count = len(repo.list_tasks())
                     marker = " (current default)" if repo.name == config.default_repo else ""
-                    click.echo(f"  {idx}. {repo.name}{marker}")
+                    click.echo(f"  {idx}. {repo.name} ({task_count} tasks){marker}")
 
                 try:
                     user_input = prompt(
@@ -304,6 +321,27 @@ def config_cmd(ctx):
                 click.echo("\nCancelled.")
 
         elif choice == "11":
+            # Set TUI view mode
+            click.echo(f"\nCurrent TUI view mode: {config.tui_view_mode}")
+            click.echo("\nView modes:")
+            click.echo("  repo     - Cycle through repositories with left/right arrows")
+            click.echo("  project  - Cycle through projects with left/right arrows")
+            click.echo("  assignee - Cycle through assignees with left/right arrows")
+            try:
+                new_mode = prompt(
+                    "Enter view mode (repo/project/assignee): ",
+                    completer=WordCompleter(["repo", "project", "assignee"], ignore_case=True),
+                )
+                new_mode = new_mode.strip().lower()
+                if new_mode in {"repo", "project", "assignee"}:
+                    config.tui_view_mode = new_mode
+                    click.secho(f"✓ TUI view mode updated to: {new_mode}", fg="green")
+                elif new_mode:
+                    click.secho("✗ Invalid view mode. Must be repo, project, or assignee.", fg="red")
+            except (KeyboardInterrupt, EOFError):
+                click.echo("\nCancelled.")
+
+        elif choice == "12":
             # Reset to defaults
             click.echo("\n⚠️  This will reset ALL configuration to defaults.")
             try:
@@ -316,10 +354,10 @@ def config_cmd(ctx):
             except (KeyboardInterrupt, EOFError):
                 click.echo("\nCancelled.")
 
-        elif choice == "12":
+        elif choice == "13":
             # Exit
             click.echo("\nExiting configuration.")
             break
 
         else:
-            click.secho("✗ Invalid choice. Please enter a number from 1-12.", fg="red")
+            click.secho("✗ Invalid choice. Please enter a number from 1-13.", fg="red")
