@@ -142,7 +142,10 @@ def prompt_repository(repositories: list[Repository], default: Optional[str] = N
         print(f"Repository: {repositories[0].name}")
         return repositories[0]
 
-    # Find the default repository's index
+    # Sort by task count (descending), then name (ascending)
+    repositories = sorted(repositories, key=lambda r: (-len(r.list_tasks()), r.name))
+
+    # Find the default repository's index (after sorting)
     default_index = None
     if default:
         for idx, repo in enumerate(repositories):
@@ -153,8 +156,9 @@ def prompt_repository(repositories: list[Repository], default: Optional[str] = N
     # Display numbered list of repositories
     print("\nAvailable repositories:")
     for idx, repo in enumerate(repositories, start=1):
+        task_count = len(repo.list_tasks())
         marker = " (default)" if default and repo.name == default else ""
-        print(f"  {idx}. {repo.name}{marker}")
+        print(f"  {idx}. {repo.name} ({task_count} tasks){marker}")
     print()
 
     # Validator for numeric choice
@@ -439,7 +443,7 @@ def prompt_status(default: str = "pending") -> str:
     Returns:
         Task status
     """
-    statuses = ["pending", "in_progress", "completed", "cancelled"]
+    statuses = ["pending", "in-progress", "completed", "cancelled"]
     completer = WordCompleter(statuses, ignore_case=True)
 
     try:
@@ -562,9 +566,9 @@ def prompt_github_enabled() -> bool:
 
     try:
         answer = prompt(
-            "Create GitHub repository? [y/N]: ",
+            "Create GitHub repository? [Y/n]: ",
             validator=YesNoValidator(),
-            default="n",
+            default="y",
         )
         return answer.strip().lower() in {"y", "yes"}
     except (KeyboardInterrupt, EOFError):
@@ -685,16 +689,30 @@ def prompt_parent_task(existing_tasks: list) -> Optional[str]:
     if not existing_tasks:
         return None
 
-    # Build completion list with task IDs and titles for easier selection
+    # Build completion list with display IDs and titles for easier selection
+    from taskrepo.utils.id_mapping import get_display_id_from_uuid
+
     task_options = []
     task_map = {}
 
     for task in existing_tasks:
-        # Format: "ID: Title"
-        display_text = f"{task.id}: {task.title}"
-        task_options.append(display_text)
-        task_map[display_text] = task.id
-        # Also allow matching by just ID
+        # Try to get display ID for this task
+        display_id = get_display_id_from_uuid(task.id)
+
+        if display_id:
+            # Format: "DisplayID: Title"
+            display_text = f"{display_id}: {task.title}"
+            task_options.append(display_text)
+            task_map[display_text] = task.id
+            # Also allow matching by just display ID
+            task_map[str(display_id)] = task.id
+        else:
+            # Fallback to UUID if no display ID found
+            display_text = f"{task.id}: {task.title}"
+            task_options.append(display_text)
+            task_map[display_text] = task.id
+
+        # Also allow matching by UUID
         task_map[task.id] = task.id
 
     completer = FuzzyWordCompleter(task_options) if task_options else None
@@ -712,13 +730,18 @@ def prompt_parent_task(existing_tasks: list) -> Optional[str]:
         # Try to find task ID from input
         parent_input = parent_input.strip()
 
+        # First, try to resolve display ID to UUID (e.g., "11" -> UUID)
+        from taskrepo.utils.helpers import normalize_task_id
+
+        normalized_id = normalize_task_id(parent_input)
+
         # Check if it matches a display text from completer
         if parent_input in task_map:
             return task_map[parent_input]
 
-        # Check if it's a direct task ID match
+        # Check if normalized ID matches any task
         for task in existing_tasks:
-            if task.id == parent_input or task.id.startswith(parent_input):
+            if task.id == normalized_id or task.id.startswith(normalized_id):
                 return task.id
 
         # If no match found, return None
