@@ -1,5 +1,6 @@
 """GitHub integration utilities."""
 
+import platform
 import shutil
 import subprocess
 from pathlib import Path
@@ -20,6 +21,22 @@ def check_gh_cli_installed() -> bool:
     return shutil.which("gh") is not None
 
 
+def get_gh_install_message() -> str:
+    """Get platform-specific installation message for GitHub CLI.
+
+    Returns:
+        Installation message with platform-specific instructions
+    """
+    base_msg = "GitHub CLI (gh) is not installed."
+
+    # Check if on macOS and if Homebrew is installed
+    if platform.system() == "Darwin" and shutil.which("brew"):
+        return f"{base_msg} Install it with:\n  brew install gh"
+
+    # Default message for other platforms or macOS without Homebrew
+    return f"{base_msg} Install it from: https://cli.github.com/"
+
+
 def check_gh_auth() -> bool:
     """Check if user is authenticated with GitHub CLI.
 
@@ -83,7 +100,7 @@ def create_github_repo(org: str, repo_name: str, visibility: str = "private") ->
     """
     # Check prerequisites
     if not check_gh_cli_installed():
-        raise GitHubError("GitHub CLI (gh) is not installed. Install it from: https://cli.github.com/")
+        raise GitHubError(get_gh_install_message())
 
     if not check_gh_auth():
         raise GitHubError("Not authenticated with GitHub. Run: gh auth login")
@@ -140,7 +157,7 @@ def clone_github_repo(org: str, repo_name: str, target_path: Path):
     """
     # Check prerequisites
     if not check_gh_cli_installed():
-        raise GitHubError("GitHub CLI (gh) is not installed. Install it from: https://cli.github.com/")
+        raise GitHubError(get_gh_install_message())
 
     if not check_gh_auth():
         raise GitHubError("Not authenticated with GitHub. Run: gh auth login")
@@ -179,3 +196,53 @@ def push_to_remote(repo_path: Path, branch: str = "main", remote_name: str = "or
     except subprocess.CalledProcessError as e:
         error_msg = e.stderr.strip() if e.stderr else str(e)
         raise GitHubError(f"Failed to push to remote: {error_msg}") from e
+
+
+def list_github_repos(org: str, pattern: str | None = None) -> list[dict]:
+    """List repositories from a GitHub organization/user.
+
+    Args:
+        org: GitHub organization or username
+        pattern: Optional pattern to filter repository names (e.g., 'tasks-*')
+
+    Returns:
+        List of repository dictionaries with 'name' and 'url' keys
+
+    Raises:
+        GitHubError: If listing fails or prerequisites not met
+    """
+    import json
+
+    # Check prerequisites
+    if not check_gh_cli_installed():
+        raise GitHubError(get_gh_install_message())
+
+    if not check_gh_auth():
+        raise GitHubError("Not authenticated with GitHub. Run: gh auth login")
+
+    try:
+        # Use gh repo list to fetch repositories
+        cmd = ["gh", "repo", "list", org, "--json", "name,url", "--limit", "1000"]
+        result = subprocess.run(cmd, capture_output=True, text=True, check=True)
+
+        # Parse JSON output
+        repos = json.loads(result.stdout)
+
+        # Filter by pattern if provided
+        if pattern:
+            # Convert shell-style glob pattern to simple prefix match
+            # For now, we'll handle 'tasks-*' as 'starts with tasks-'
+            if pattern.endswith("*"):
+                prefix = pattern[:-1]
+                repos = [r for r in repos if r["name"].startswith(prefix)]
+            else:
+                # Exact match
+                repos = [r for r in repos if r["name"] == pattern]
+
+        return repos
+
+    except subprocess.CalledProcessError as e:
+        error_msg = e.stderr.strip() if e.stderr else str(e)
+        raise GitHubError(f"Failed to list GitHub repositories: {error_msg}") from e
+    except json.JSONDecodeError as e:
+        raise GitHubError(f"Failed to parse GitHub response: {e}") from e
